@@ -1,10 +1,8 @@
-from __future__ import absolute_import
-
-from .secp256k1 import (  # noqa: F401
-    privtopub,
-    ecdsa_raw_sign,
-    ecdsa_raw_recover,
+from .secp256k1 import (
+    G,
     N,
     P,
-    G,
+    ecdsa_raw_recover,
+    ecdsa_raw_sign,
+    privtopub,
 )
